package Task::Perinci;

our $VERSION = '0.16'; # VERSION

1;
# ABSTRACT: Install all Perinci-related modules

__END__

=pod

=encoding utf-8

=head1 NAME

Task::Perinci - Install all Perinci-related modules

=head1 VERSION

version 0.16

=head1 DESCRIPTION

This task will install all Perinci-related modules.

=head1 FUNCTIONS


None are exported by default, but they are exportable.

=head1 TASK CONTENTS

=head2 Included modules

=head3 L<Perinci>

=head3 L<Perinci::Access>

=head3 L<Perinci::Access::Base>

=head3 L<Perinci::Access::HTTP::Client>

=head3 L<Perinci::Access::HTTP::Server>

=head3 L<Perinci::Access::Perl>

=head3 L<Perinci::Access::Simple::Client>

=head3 L<Perinci::Access::Simple::Server>

=head3 L<Perinci::CmdLine>

=head3 L<Perinci::Easy>

=head3 L<Perinci::Examples>

=head3 L<Perinci::Examples::Bin>

=head3 L<Perinci::Exporter>

=head3 L<Perinci::Gen::ForModule>

=head3 L<Perinci::Object>

=head3 L<Perinci::Result::Format>

=head3 L<Perinci::Sub::Complete>

=head3 L<Perinci::Sub::ConvertArgs::Array>

=head3 L<Perinci::Sub::ConvertArgs::Argv>

=head3 L<Perinci::Sub::Dep::pm>

=head3 L<Perinci::Sub::DepChecker>

=head3 L<Perinci::Sub::Gen>

=head3 L<Perinci::Sub::Gen::AccessTable>

=head3 L<Perinci::Sub::Gen::AccessTable::DBI>

=head3 L<Perinci::Sub::GetArgs::Argv>

=head3 L<Perinci::Sub::GetArgs::Array>

=head3 L<Perinci::Sub::Property::curry>

=head3 L<Perinci::Sub::Property::dies_on_error>

=head3 L<Perinci::Sub::Property::drops_privilege>

=head3 L<Perinci::Sub::Property::retry>

=head3 L<Perinci::Sub::Property::timeout>

=head3 L<Perinci::Sub::PropertyUtil>

# =pkg Perinci::Sub::To::ReForm

=head3 L<Perinci::Sub::Wrapper>

=head3 L<Perinci::To::HTML>

=head3 L<Perinci::To::POD>

=head3 L<Perinci::To::Text>

=head3 L<Perinci::Tx::Manager>

=head3 L<Perinci::Use>

=head3 L<Perinci::Util>

=head3 L<Perinci::Web>

=head3 L<Pod::Weaver::Plugin::Perinci>

=head3 L<Riap>

=head3 L<Rinci>

=head3 L<Rinci::Schema>

=head3 L<Test::Rinci>

=head3 L<Gen::Test::Rinci::FuncResult>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Task-Perinci>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-Task-Perinci>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://rt.cpan.org/Public/Dist/Display.html?Name=Task-Perinci>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
